Mixed-Up Code Exercises
------------------------

Answer the following **Mixed-Up Code** or **Activecode** questions to
assess what you have learned in this chapter.

.. selectquestion:: vectors_p1_sq
   :fromid: vectors_p1, vectors_p1_ac_q
   :toggle:

.. selectquestion:: vectors_p2_sq
   :fromid: vectors_p2, vectors_p2_ac_q
   :toggle:

.. selectquestion:: vectors_p3_sq
   :fromid: vectors_p3, vectors_p3_ac_q
   :toggle:

.. selectquestion:: vectors_p4_sq
   :fromid: vectors_p4, vectors_p4_ac_q
   :toggle:

.. selectquestion:: vectors_p5_sq
   :fromid: vectors_p5, vectors_p5_ac_q
   :toggle:

.. selectquestion:: vectors_p6_sq
   :fromid: vectors_p6, vectors_p6_ac_q
   :toggle:

.. selectquestion:: vectors_p7_sq
   :fromid: vectors_p7, vectors_p7_ac_q
   :toggle:

.. selectquestion:: vectors_p8_sq
   :fromid: vectors_p8, vectors_p8_ac_q
   :toggle:

.. selectquestion:: vectors_p9_sq
   :fromid: vectors_p9, vectors_p9_ac_q
   :toggle:

.. selectquestion:: vectors_p10_sq
   :fromid: vectors_p10, vectors_p10_ac_q
   :toggle:
